==> pf4-component-mapper-3.23.0.tgz: package/esm/form-group/form-group.js <==
import _extends from "@babel/runtime/helpers/extends";
import React from 'react';
import { FormGroup as Pf4FormGroup } from "@patternfly/react-core/dist/dynamic/components/Form";
import { TextContent } from "@patternfly/react-core/dist/dynamic/components/Text";
import { Text } from "@patternfly/react-core/dist/dynamic/components/Text";
import { FormHelperText } from "@patternfly/react-core/dist/dynamic/components/Form";
import { HelperText } from "@patternfly/react-core/dist/dynamic/components/HelperText";
import { HelperTextItem } from "@patternfly/react-core/dist/dynamic/components/HelperText";
import PropTypes from 'prop-types';
import showError from '../show-error/show-error';

var FormGroup = function FormGroup(_ref) {
  var label = _ref.label,
      isRequired = _ref.isRequired,
      helperText = _ref.helperText,
      meta = _ref.meta,
      validateOnMount = _ref.validateOnMount,
      description = _ref.description,
      hideLabel = _ref.hideLabel,
      children = _ref.children,
      id = _ref.id,
      FormGroupProps = _ref.FormGroupProps;

  var _showError = showError(meta, validateOnMount),
      validated = _showError.validated;

  var validationInternal = (meta.touched || validateOnMount) && (meta.error || meta.submitError || meta.warning);
  return /*#__PURE__*/React.createElement(Pf4FormGroup, _extends({
    isRequired: isRequired,
    label: !hideLabel && label,
    fieldId: id,
    "aria-label": meta.error || meta.submitError
  }, FormGroupProps), description && /*#__PURE__*/React.createElement(TextContent, null, /*#__PURE__*/React.createElement(Text, {
    component: "small"
  }, description)), children, (helperText || ['error', 'warning'].includes(validated)) && /*#__PURE__*/React.createElement(FormHelperText, null, /*#__PURE__*/React.createElement(HelperText, null, /*#__PURE__*/React.createElement(HelperTextItem, {
    variant: validated
  }, validationInternal || helperText))));
};

FormGroup.propTypes = {
  label: PropTypes.node,
  isRequired: PropTypes.bool,
  helperText: PropTypes.node,
  meta: PropTypes.object.isRequired,
  description: PropTypes.node,
  hideLabel: PropTypes.bool,
  validateOnMount: PropTypes.bool,
  id: PropTypes.string.isRequired,
  children: PropTypes.oneOfType([PropTypes.element, PropTypes.arrayOf(PropTypes.element)]).isRequired,
  FormGroupProps: PropTypes.object
};
export default FormGroup;

==> pf4-component-mapper-4.0.0.tgz: package/esm/form-group/form-group.js <==
import _extends from "@babel/runtime/helpers/extends";
import React from 'react';
import { FormGroup as Pf4FormGroup } from "@patternfly/react-core/dist/dynamic/components/Form";
import { Content } from "@patternfly/react-core/dist/dynamic/components/Content";
import { FormHelperText } from "@patternfly/react-core/dist/dynamic/components/Form";
import { HelperText } from "@patternfly/react-core/dist/dynamic/components/HelperText";
import { HelperTextItem } from "@patternfly/react-core/dist/dynamic/components/HelperText";
import PropTypes from 'prop-types';
import showError from '../show-error/show-error';

var FormGroup = function FormGroup(_ref) {
  var label = _ref.label,
      isRequired = _ref.isRequired,
      helperText = _ref.helperText,
      meta = _ref.meta,
      validateOnMount = _ref.validateOnMount,
      description = _ref.description,
      hideLabel = _ref.hideLabel,
      children = _ref.children,
      id = _ref.id,
      FormGroupProps = _ref.FormGroupProps;

  var _showError = showError(meta, validateOnMount),
      validated = _showError.validated;

  var validationInternal = (meta.touched || validateOnMount) && (meta.error || meta.submitError || meta.warning);
  return /*#__PURE__*/React.createElement(Pf4FormGroup, _extends({
    isRequired: isRequired,
    label: !hideLabel && label,
    fieldId: id,
    "aria-label": meta.error || meta.submitError
  }, FormGroupProps), description && /*#__PURE__*/React.createElement(Content, null, /*#__PURE__*/React.createElement(Content, {
    component: "small"
  }, description)), children, (helperText || ['error', 'warning'].includes(validated)) && /*#__PURE__*/React.createElement(FormHelperText, null, /*#__PURE__*/React.createElement(HelperText, null, /*#__PURE__*/React.createElement(HelperTextItem, {
    variant: validated
  }, validationInternal || helperText))));
};

FormGroup.propTypes = {
  label: PropTypes.node,
  isRequired: PropTypes.bool,
  helperText: PropTypes.node,
  meta: PropTypes.object.isRequired,
  description: PropTypes.node,
  hideLabel: PropTypes.bool,
  validateOnMount: PropTypes.bool,
  id: PropTypes.string.isRequired,
  children: PropTypes.oneOfType([PropTypes.element, PropTypes.arrayOf(PropTypes.element)]).isRequired,
  FormGroupProps: PropTypes.object
};
export default FormGroup;
